@@ -3,8 +3,10 @@ pub mod list;
 pub mod template;
 pub mod consts;
 pub mod error;
+pub mod config_multi;
 
 pub use config::*;
+pub use config_multi::*;
 pub use list::*;
 pub use template::*;
 pub use consts::*;
